==> gazie7.30.zip: gazie/language/italian/menu.inc.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$strCommon = array('cancel' => " Annulla ",
    'return' => " Indietro ",
    'submit' => " CONFERMA ",
    'view' => " ANTEPRIMA ",
    'print' => " STAMPA ",
    'search' => " Cerca ",
    'change' => " Cambia ",
    'all' => 'Tutti',
    'none' => 'Nessuno',
    'vall' => " Mostra tutti ",
    'delete' => " Elimina ",
    'first' => "Primo",
    'prev' => "precedente",
    'next' => "successivo",
    'last' => "Ultimo",
    'order' => "ordina per ",
    'selall' => "Seleziona tutto",
    'invsel' => "Inverti selezione",
    'error' => "ERRORE",
    'warning' => "ATTENZIONE",
    'cancel' => "Annulla ",
    'update' => "Modifica ",
    'insert' => "Inserisci ",
    'wait' => 'Attendere',
    'wait_al' => "Basta! Smettila di cliccare!",
    'notfound' => " non trovato ",
    'minins' => " inserire min.",
    'charat' => " caratteri ",
    'changedate' => "Cambia la data",
    'pullup' => "Tira su il rigo",
    'thisrow' => " questo rigo",
    'insrow' => "Righi inseriti",
    'addrow' => "Aggiungi rigo",
    'delrow' => "Elimina rigo",
    'safe' => " se sei sicuro clicca su ",
    'youdel' => " Stai eliminando",
    'yes' => "Si",
    'no' => "No",
    'page' => "pagina ",
    'of' => " di ",
    'of_the' => " del ",
    'sqn' => "I campi contrassegnati con * sono obbligatori!",
    'canc' => "Annulla le modifiche apportate alla schermata",
    'ins' => "Accetta tutto e inserisci",
    'upd' => "Accetta tutto e modifica",
    'caps' => "Blocco maiuscole attivato!",
    'typerow' => array(0 => 'Normale', 1 => 'Forfait', 2 => 'Descrittivo', 3 => 'Var.totale fatt', 4 => 'Cassa previdenziale', 6 => 'Testo', 7 => 'Solo su DdT', 8 => 'Solo su Fatt', 11 => 'Codice CIG (FaE 2.1.X.7)', 12 => 'Codice CUP (FaE 2.1.X.6)', 13 => 'Id.Documento (FaE 2.1.X.2)', 14 => 'Data Documento (FaE 2.1.X.3)', 15 => 'Num.Linea ordine (FaE 2.1.X.4)', 16 => 'Codice Commessa (FaE 2.1.X.5)', 21 => 'Causale (FaE 2.1.1.11)', 25 => 'SAL Riferm.Fase (FaE 2.1.7)', 31 => 'Dati Veicoli (FaE 2.3)', 50 => 'Normale c/allegato', 51 => 'Descritt. c/allegato', 90 => 'Vendita cespite'),
    'search_item' => array('C' => 'Codice articolo', 'B' => 'Codice a barre', 'D' => 'Descrizione'),
    'tipiva' => array('I' => 'Imponibile', 'N' => 'Non Imponibile', 'E' => 'Esente', 'S' => 'Non Soggetto', 'C' => 'Escluso', 'D' => 'Indetraibile', 'P' => 'In sospensione', 'T' => 'Split payment'),
    'duplicate' => 'Duplica',
    'browse_for_file' => 'Sfoglia',
	'refresh' => ' AGGIORNA ',
	'add' => 'Aggiungi movimento',
    'order_type' => array(""=>'',"AGR"=>'Agricola', "IND"=>'Industriale', "RIC"=>'Ricerca e sviluppo', "PRF"=>'Professionale', "ART"=>'Artigianale'),
    'business' => "per la gestione aziendale.",
    'proj' => "Progetto di: ",
    'auth' => "Sito dell'autore"
);

==> gazie8.00.zip: gazie/language/italian/menu.inc.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$strCommon = array('cancel' => " Annulla ",
    'return' => " Indietro ",
    'submit' => " Conferma ",
    'view' => " Anteprima ",
    'print' => " Stampa ",
    'search' => " Cerca ",
    'change' => " Cambia ",
    'all' => 'Tutti',
    'none' => 'Nessuno',
    'vall' => " Mostra tutti ",
    'delete' => " Elimina ",
    'first' => "Primo",
    'prev' => "precedente",
    'next' => "successivo",
    'last' => "Ultimo",
    'order' => "ordina per ",
    'selall' => "Seleziona tutto",
    'invsel' => "Inverti selezione",
    'error' => "ERRORE",
    'warning' => "ATTENZIONE",
    'cancel' => "Annulla ",
    'update' => "Modifica ",
    'insert' => "Inserisci ",
    'wait' => 'Attendere',
    'wait_al' => "Attenti prima di cliccare nuovamente",
    'notfound' => " non trovato ",
    'minins' => " inserire min.",
    'charat' => " caratteri ",
    'changedate' => "Cambia la data",
    'pullup' => "Tira su il rigo",
    'thisrow' => " questo rigo",
    'insrow' => "Righi inseriti",
    'addrow' => "Aggiungi rigo",
    'delrow' => "Elimina rigo",
    'safe' => " se sei sicuro clicca su ",
    'youdel' => " Stai eliminando",
    'yes' => "Si",
    'no' => "No",
    'page' => "pagina ",
    'of' => " di ",
    'of_the' => " del ",
    'sqn' => "I campi contrassegnati con * sono obbligatori!",
    'canc' => "Annulla le modifiche apportate alla schermata",
    'ins' => "Accetta tutto e inserisci",
    'upd' => "Accetta tutto e modifica",
    'caps' => "Blocco maiuscole attivato!",
    'typerow' => array(0 => 'Normale', 1 => 'Forfait', 2 => 'Descrittivo', 3 => 'Var.totale fatt', 4 => 'Cassa previdenziale', 6 => 'Testo', 7 => 'Solo su DdT', 8 => 'Solo su Fatt', 11 => 'Codice CIG (FaE 2.1.X.7)', 12 => 'Codice CUP (FaE 2.1.X.6)', 13 => 'Id.Documento (FaE 2.1.X.2)', 14 => 'Data Documento (FaE 2.1.X.3)', 15 => 'Num.Linea ordine (FaE 2.1.X.4)', 16 => 'Codice Commessa (FaE 2.1.X.5)', 21 => 'Causale (FaE 2.1.1.11)', 25 => 'SAL Riferm.Fase (FaE 2.1.7)', 31 => 'Dati Veicoli (FaE 2.3)', 50 => 'Normale c/allegato', 51 => 'Descritt. c/allegato', 90 => 'Vendita cespite'),
    'search_item' => array('C' => 'Codice articolo', 'B' => 'Codice a barre', 'D' => 'Descrizione'),
    'tipiva' => array('I' => 'Imponibile', 'N' => 'Non Imponibile', 'E' => 'Esente', 'S' => 'Non Soggetto', 'C' => 'Escluso', 'D' => 'Indetraibile', 'P' => 'In sospensione', 'T' => 'Split payment', 'M' => 'Reg.margine/non esp.','R'=>'Reverse Charge'),
    'flux_status_val' => array('DI' => array('da inviare','default'), 'IN' => array('inviata','info'), 'PC' => array('presa in carico','info'), 'RC' => array('consegnata','success'), 'NS' => array('scartata','danger'), 'MC' => array('non consegnata','warning'), 'NA' => array('accettata','success'), 'NR' => array('rifiutata','danger'), 'AT' => array('recapito impossibile','danger'), 'DT' => array('decorrenza termini','warning')),
    'duplicate' => 'Duplica',
    'browse_for_file' => 'Sfoglia',
	'refresh' => ' Aggiorna ',
	'add' => 'Aggiungi movimento',
    'order_type' => array(""=>'',"AGR"=>'Agricola', "IND"=>'Industriale', "RIC"=>'Ricerca e sviluppo', "PRF"=>'Professionale', "ART"=>'Artigianale'),
    'business' => "per la gestione aziendale.",
    'proj' => "Progetto di: ",
    'auth' => "Sito dell'autore"
);
